# HealthControllerCheck200ResponseInfoValue


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | **str** |  | 

## Example

```python
from montelo.client.models.health_controller_check200_response_info_value import HealthControllerCheck200ResponseInfoValue

# TODO update the JSON string below
json = "{}"
# create an instance of HealthControllerCheck200ResponseInfoValue from a JSON string
health_controller_check200_response_info_value_instance = HealthControllerCheck200ResponseInfoValue.from_json(json)
# print the JSON string representation of the object
print HealthControllerCheck200ResponseInfoValue.to_json()

# convert the object into a dict
health_controller_check200_response_info_value_dict = health_controller_check200_response_info_value_instance.to_dict()
# create an instance of HealthControllerCheck200ResponseInfoValue from a dict
health_controller_check200_response_info_value_form_dict = health_controller_check200_response_info_value.from_dict(health_controller_check200_response_info_value_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


